import os
import stripe
import logging
log = logging.getLogger(__name__)

def create_stripe_payment_intent(
        amount: float, 
        booking_id: str,
        currency: str = "AUD",
    ):
    try:
        payment_intent = stripe.PaymentIntent.create(
            api_key=os.environ['STRIPE_API_KEY'],
            amount=int(amount*100),
            currency=currency,
            payment_method_types=[ x.strip() for x in os.getenv(
                'STRIPE_PAYMENT_METHODS','card').split(',') ],
            # payment_method_types=['card'], # TODO add more payment methods
            description="payment for booking: " + booking_id,
            metadata={
                "booking_id": booking_id
            },
        )
        return {"StripeClientSecret": payment_intent["client_secret"]}
    except Exception as e:
        log.error(e)
        return {
            "error": "Failed to create payment intent",
            "StripeClientSecret": None
        }
def cancel_stripe_payment_intent(
        payment_intent_id: str,
    ):
    try:
        payment_intent = stripe.PaymentIntent.cancel(
            api_key=os.environ['STRIPE_API_KEY'],
            idempotency_key=payment_intent_id,
        )
        return {"status": payment_intent["status"]}
    except Exception as e:
        log.error(e)
        return {
            "error": "Failed to cancel payment intent",
        }